@@ -12,7 +12,7 @@ use AnyEvent::WebSocket::Connection;
 use PerlX::Maybe qw( maybe provided );
 
 # ABSTRACT: WebSocket client for AnyEvent
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 
 has timeout => (
@@ -115,7 +115,7 @@ AnyEvent::WebSocket::Client - WebSocket client for AnyEvent
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -197,7 +197,9 @@ SSL/TLS verification.
 
 =head1 METHODS
 
-=head2 $client-E<gt>connect($uri)
+=head2 connect
+
+ my $cv = $client->connect($uri)
 
 Open a connection to the web server and open a WebSocket to the resource
 defined by the given URL.  The URL may be either an instance of L<URI::ws>,
@@ -250,15 +252,6 @@ This is pretty simple minded and there are probably WebSocket features
 that you might like to use that aren't supported by this distribution.
 Patches are encouraged to improve it.
 
-If you see warnings like this:
-
- Class::MOP::load_class is deprecated at .../Class/MOP.pm line 71.
- Class::MOP::load_class("Crypt::Random::Source::Weak::devurandom") called at .../Crypt/Random/Source/Factory.pm line 137
- ...
-
-The problem is in the optional L<Crypt::Random::Source> module, and 
-reportedly been fixed in its version 0.08.
-
 =head1 SEE ALSO
 
 =over 4
@@ -305,8 +298,6 @@ L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
 
 =back
 
-=cut
-
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
