@@ -12,7 +12,7 @@ use AnyEvent::WebSocket::Message;
 use Carp qw( croak carp );
 
 # ABSTRACT: WebSocket connection for AnyEvent
-our $VERSION = '0.30'; # VERSION
+our $VERSION = '0.31'; # VERSION
 
 
 has handle => (
@@ -178,37 +178,6 @@ sub close
   $self->send(AnyEvent::WebSocket::Message->new(opcode => 8, body => ""));
   $self->handle->push_shutdown;
   $self->_is_write_open(0);
-}
-
-
-
-sub on_each_message
-{
-  my($self, $cb) = @_;
-  carp "on_each_message is deprecated" if warnings::enabled('deprecated');
-  $self->on(each_message => sub {
-    $cb->(Encode::decode("UTF-8",pop->body));
-  });
-  $self;
-}
-
-
-sub on_next_message
-{
-  my($self, $cb) = @_;
-  carp "on_next_message is deprecated" if warnings::enabled('deprecated');
-  $self->on(next_message => sub {
-    $cb->(Encode::decode("UTF-8",pop->body));
-  });
-  $self;
-}
-
-
-sub on_finish
-{
-  my($self, $cb) = @_;
-  carp "on_finish is deprecated" if warnings::enabled('deprecated');
-  $self->on(finish => $cb);
   $self;
 }
 
@@ -226,7 +195,7 @@ AnyEvent::WebSocket::Connection - WebSocket connection for AnyEvent
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
@@ -286,13 +255,19 @@ If set to true, it masks outgoing frames. The default is false.
 
 =head1 METHODS
 
-=head2 $connection-E<gt>send($message)
+=head2 send
+
+ $connection->send($message);
 
 Send a message to the other side.  C<$message> may either be a string
 (in which case a text message will be sent), or an instance of
 L<AnyEvent::WebSocket::Message>.
 
-=head2 $connection-E<gt>on($event => $cb)
+=head2 on
+
+ $connection->on(each_message => $cb);
+ $connection->on(each_message => $cb);
+ $connection->on(finish => $cb);
 
 Register a callback to a particular event.
 
@@ -319,7 +294,9 @@ Called when the connection is terminated
 
 =head3
 
-=head2 $connection-E<gt>close
+=head2 close
+
+ $connection->close;
 
 Close the connection.
 
@@ -331,32 +308,6 @@ connections.  For details, contact the author and/or take a look at the
 source for L<AnyEvent::WebSocket::Client> and the examples that come with
 L<Protocol::WebSocket>.
 
-=head1 DEPRECATED METHODS
-
-The methods in this section are deprecated and will be removed on or
-after 11 October 2015, at which point they will have been deprecated
-for two years.   They should not be used for new code, and are only
-remain documented here to aid in understanding legacy code that use
-them.
-
-=head2 $connection-E<gt>on_each_message($cb)
-
-Register a callback to be called on each subsequent message received.
-The message itself will be passed in as the only parameter to the
-callback.
-The message is a decoded text string.
-
-=head2 $connection-E<gt>on_next_message($cb)
-
-Register a callback to be called the next message received.
-The message itself will be passed in as the only parameter to the
-callback.
-The message is a decoded text string.
-
-=head2 $connection-E<gt>on_finish($cb)
-
-Register a callback to be called when the connection is closed.
-
 =head1 SEE ALSO
 
 =over 4
@@ -383,8 +334,6 @@ L<RFC 6455 The WebSocket Protocol|http://tools.ietf.org/html/rfc6455>
 
 =back
 
-=cut
-
 =head1 AUTHOR
 
 Author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
